==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/entity/VisualPowerPointInfo.java <==
package org.springblade.visual.entity;

import java.io.Serializable;
import java.time.LocalDateTime;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.SqlCondition;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 幻灯片表 visual_power_point_info
 * 
 * @author wookvn
 * @date 2023-02-04
 */
@Data
@TableName("visual_power_point_info")
@ApiModel(value = "VisualPowerPointInfo对象", description = "幻灯片")
public class VisualPowerPointInfo implements Serializable{

	private static final long serialVersionUID = 1L;
	
 	/** 
	 *  
	 */
	@TableId(type = IdType.AUTO)
	private Integer id;
	
	/** 
	 * 分类ID 
	 */
	@ApiModelProperty(value = "分类ID")
	private Integer cateId;

	/** 
	 * 幻灯片名称 
	 */
	@ApiModelProperty(value = "幻灯片名称")
	@TableField(condition = SqlCondition.LIKE)
	private String ppName;

	/** 
	 * 幻灯片设置 
	 */
	@ApiModelProperty(value = "幻灯片设置JSON字符串，前端使用")
	private String settings;

	/** 
	 * 大屏ID列表，逗号分隔 
	 */
	@ApiModelProperty(value = "大屏ID列表[按顺序逗号分隔]")
	private String visualIds;

	/** 
	 * 创建人ID 
	 */
	@ApiModelProperty(value = "创建人ID[系统自动添加]")
	private Long createUserId;

	/** 
	 * 创建时间 
	 */
	@ApiModelProperty(value = "创建时间[系统自动添加]")
	private LocalDateTime createTime;

	/** 
	 * 修改人 
	 */
	@ApiModelProperty(value = "修改人[系统自动添加]")
	private String updateBy;

	/** 
	 * 修改时间 
	 */
	@ApiModelProperty(value = "修改时间[系统自动添加]")
	private LocalDateTime updateTime;
}

==> v1.1.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/entity/VisualPowerPointInfo.java <==
package org.springblade.visual.entity;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.SqlCondition;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 幻灯片表 visual_power_point_info
 * 
 * @author wookvn
 * @date 2023-02-04
 */
@Data
@TableName("visual_power_point_info")
@ApiModel(value = "VisualPowerPointInfo对象", description = "幻灯片")
public class VisualPowerPointInfo implements Serializable{

	private static final long serialVersionUID = 1L;
	
 	/** 
	 *  
	 */
	@TableId(type = IdType.AUTO)
	private Integer id;
	
	/** 
	 * 分类ID 
	 */
	@ApiModelProperty(value = "分类ID")
	private Integer cateId;

	/** 
	 * 幻灯片名称 
	 */
	@ApiModelProperty(value = "幻灯片名称")
	@TableField(condition = SqlCondition.LIKE)
	private String ppName;
	
	/**
	 * 幻灯片月份
	 */
	@ApiModelProperty(value = "幻灯片月份")
	private String ppMonth;

	/** 
	 * 幻灯片设置 
	 */
	@ApiModelProperty(value = "幻灯片设置JSON字符串，前端使用")
	private String settings;

	/** 
	 * 创建人ID 
	 */
	@ApiModelProperty(value = "创建人ID[系统自动添加]")
	private Long createUserId;

	/** 
	 * 创建时间 
	 */
	@ApiModelProperty(value = "创建时间[系统自动添加]")
	private LocalDateTime createTime;

	/** 
	 * 修改人 
	 */
	@ApiModelProperty(value = "修改人[系统自动添加]")
	private String updateBy;

	/** 
	 * 修改时间 
	 */
	@ApiModelProperty(value = "修改时间[系统自动添加]")
	private LocalDateTime updateTime;
	
	/**
	 * 大屏数量
	 */
	@ApiModelProperty(value = "大屏数量")
	@TableField(exist = false)
	private int visualCount;
	
	/** 
	 * 大屏ID列表 - 冗余字段，传参数使用
	 */
	@ApiModelProperty(value = "大屏ID列表[按顺序逗号分隔]")
	@TableField(exist = false)
	private List<String> visualIds;
}
